{% extends "admin/base_site.html" %}
{% load i18n %}

{% block extrastyle %}{{ block.super }}
<style type="text/css">
    /* minimal style for the diffs */
    del, ins {
        color: #000;
        text-decoration: none;
    }
    del { background-color: #ffe6e6; }
    ins { background-color: #e6ffe6; }
    sup.follow { color: #5555ff; }
</style>
{% endblock %}

{% block breadcrumbs %}
    <div class="breadcrumbs">
        <a href="{% url 'admin:index' %}">{% trans 'Home' %}</a> &rsaquo;
        <a href="{% url 'admin:app_list' app_label %}">{{app_label|capfirst|escape}}</a> &rsaquo; 
        <a href="{{changelist_url}}">{{opts.verbose_name_plural|capfirst}}</a> &rsaquo;
        <a href="{{history_url}}">{% trans "History" %}</a> &rsaquo;
        {% blocktrans with opts.verbose_name_plural|escape as name %}Compare {{name}}{% endblocktrans %}
        {{title}}
    </div>
{% endblock %}


{% block content %}
    <div id="content-main">

{% comment %}
        {% block object-tools %}
            <ul class="object-tools">
              {% block object-tools-items %}
                {% if prev_url %}<li><a href="{{ prev_url }}">&lsaquo; {% trans "previous" %}</a></li>{% endif %}
                {% if next_url %}<li><a href="{{ next_url }}">{% trans "next" %} &rsaquo;</a></li>{% endif %}
              {% endblock %}
            </ul>
        {% endblock %}
{% endcomment %}
        
        <p class="help">
            {% blocktrans with date1=version1.revision.date_created|date:_("DATETIME_FORMAT") date2=version2.revision.date_created|date:_("DATETIME_FORMAT") %}
                Compare <strong>{{ date1 }}</strong> with <strong>{{ date2 }}</strong>:
            {% endblocktrans %}
        </p>
        &lsaquo; <a href="{{history_url}}">{% trans "Go back to history list" %}</a>
        {% for field_diff in compare_data %}
            <h3>{% firstof field_diff.field.verbose_name field_diff.field.related_name %}{% if field_diff.is_related and not field_diff.follow %}<sup class="follow">*</sup>{% endif %}</h3>
            {% if field_diff.field.help_text %}<p class="help">{{ field_diff.field.help_text }}</p>{% endif %}
            <div class="module">
                <p>{{ field_diff.diff }}</p>
            </div>
        {% empty %}
            <div class="module">
                <p><strong>There are no differences.</strong></p>
            </div>
        {% endfor %}

        <h4>{% trans "Edit comment:" %}</h4>
        <blockquote>{{ version2.revision.comment|default:"(there exist not comment)" }}</blockquote>

        {% if has_unfollowed_fields %}
        <h4 class="follow">{% trans "Note:" %}</h4>
        <p class="follow">
            Fields/entries marked with <sup class="follow">*</sup> are not under reversion control.
            It may be that not all marked information are correct.
        </p>
        {% endif %}

        &lsaquo; <a href="{{history_url}}">{% trans "Go back to history list" %}</a>
    </div>
{% endblock %}
