<!DOCTYPE html>
<html>
  <head><title></title></head>
  <body>
    <script type="text/javascript">
      opener.dismissAddAnotherPopup(window, "{{ value }}", "{{ obj }}");
    </script>
  </body>
</html>
